Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDarin Swanson2002-06-05 20:55:18 +0000
committerDarin Swanson2002-06-05 20:55:18 +0000
commitc5d6516cce4c92dd2be69399bd93aa0eb0495312 (patch)
tree359a00c66a1eeaa751912676306e122ba7779d89 /org.eclipse.debug.ui/ui
parent3c17f299afb68e75e9acf592e26ff3fd7283bb49 (diff)
downloadeclipse.platform.debug-c5d6516cce4c92dd2be69399bd93aa0eb0495312.tar.gz
eclipse.platform.debug-c5d6516cce4c92dd2be69399bd93aa0eb0495312.tar.xz
eclipse.platform.debug-c5d6516cce4c92dd2be69399bd93aa0eb0495312.zip
Bug 19379 - Debug remembers selected state of toolbar entry even if it is no longer enabled
Diffstat (limited to 'org.eclipse.debug.ui/ui')
-rw-r--r--org.eclipse.debug.ui/ui/org/eclipse/debug/ui/AbstractDebugView.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/org.eclipse.debug.ui/ui/org/eclipse/debug/ui/AbstractDebugView.java b/org.eclipse.debug.ui/ui/org/eclipse/debug/ui/AbstractDebugView.java
index 1b88a3296..2887b4341 100644
--- a/org.eclipse.debug.ui/ui/org/eclipse/debug/ui/AbstractDebugView.java
+++ b/org.eclipse.debug.ui/ui/org/eclipse/debug/ui/AbstractDebugView.java
@@ -550,7 +550,7 @@ public abstract class AbstractDebugView extends PageBookView implements IDebugVi
}
/**
* Persists the state of the check box actions contributed
* to this view.
*
* @see IViewPart#saveState(IMemento)
@@ -569,7 +569,7 @@ public abstract class AbstractDebugView extends PageBookView implements IDebugVi
if (iContributionItem instanceof ActionContributionItem) {
ActionContributionItem item= (ActionContributionItem)iContributionItem;
IAction action= item.getAction();
- if (action.getStyle() == IAction.AS_CHECK_BOX) {
+ if (action.getStyle() == IAction.AS_CHECK_BOX && action.isEnabled()) {
saveActionState(memento, action);
}
}
@@ -550,7 +550,7 @@ public abstract class AbstractDebugView extends PageBookView implements IDebugVi
}
/**
- * Persists the state of the check box actions contributed
+ * Persists the state of the enabled check box actions contributed
* to this view.
*

Back to the top